@@ -114,11 +114,12 @@ public class FormJson extends #1.SuperPage {
 		else {
 			HttpSession	session = req.getSession();
 			JSON	data = Ajax.get( session, from.getUniqueKey() );
+			buf = buf.append( "if(parent.paraselene_called_form){" );
 			buf = buf.append( "parent.paraselene_called_form.target='_self';" );
 			buf = buf.append( "parent.paraselene_called_form=undefined;" );
 			buf = buf.append( "parent.paraselene_action(" );
 			buf = buf.append( data.toString() );
-			buf = buf.append( ");" );
+			buf = buf.append( ");}else{history.forward();}" );
 		}
 		script.removeHTMLPart();
 		script.addHTMLPart( new paraselene.ajax.data.JavaScript( buf.toString() ) );
