@@ -1,5 +1,6 @@
 package #1.#y#2;
 
+import paraselene.*;
 import paraselene.supervisor.*;
 import paraselene.dyna.*;
 
@@ -36,6 +37,12 @@ return #1.#x.PageType.#6;
 public Forward inputMain( RequestParameter req, Forward fw ) throws PageException {
 return new Forward( 403 );
 }
+/**
+ * 初回outputの呼び出しメイン処理。
+ * @param req リクエスト内容。
+ * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
+ */
+public void firstOutputMain( RequestParameter req ) throws PageException {}
 /**
  * 履歴追加方法。<br>
  * History.add()を行う際に呼ばれる。
