@@ -824,9 +824,7 @@ public abstract class Page implements Serializable {
 
 		String	name = tag.getNameAttribute();
 		if ( name != null ) {
-			if ( Form.FORM_ID.equals( name ) )	return;
-			if ( Form.FORM_AJAX.equals( name ) )	return;
-			if ( Form.FORM_DUMMY.equals( name ) )	return;
+			if ( Form.isFixedName( name ) )	return;
 		}
 		nameTagSingle( tag );
 		int	cnt = tag.getHTMLPartCount();
