@@ -234,7 +234,7 @@ public class Forward implements Serializable {
 			if ( error == 403 ) {
 				Option.traceWithStack( "403 Forward" );
 			}
-			res.sendError( error );
+			ErrorStatus.send( res, error );
 			return;
 		}
 		if ( redirect_uri != null ) {
