@@ -11,6 +11,8 @@ import java.util.*;
 import java.util.concurrent.locks.*;
 import java.io.*;
 import paraselene.*;
+import paraselene.ajax.data.*;
+import paraselene.ajax.*;
 
 /**
  * 画面遷移履歴。<br>
@@ -27,6 +29,13 @@ public class History implements Serializable {
 	volatile boolean drop_f = false;
 	volatile String	session_id;
 
+	private void comet_stop( Page p ) {
+		StringBuilder	buf = new StringBuilder( "paraselene_comet_stop('" );
+		buf = buf.append( p.getUniqueKey() );
+		buf = buf.append( "');" );
+		Ajax.addComet( session_id, new PostBack( new Exec( buf.toString() ) ) );
+	}
+
 	boolean tryLock() {
 		if ( lock.isHeldByCurrentThread() )	return true;
 		Option.trace( "call tryLock " );
@@ -43,6 +52,7 @@ public class History implements Serializable {
 	}
 
 	void unlock() {
+		if ( !lock.isHeldByCurrentThread() )	return;
 		Option.trace( "call unlock " );
 		lock.unlock();
 		Option.trace( "unlocked " );
@@ -65,6 +75,7 @@ public class History implements Serializable {
 		if ( page == null )	return;
 		synchronized( popup ) {
 			removePopup( page );
+			setInfo( page );
 			popup.add( page );
 		}
 		Option.trace( "addSatellitePage %d %s", hashCode(), page.getUniqueKey() );
@@ -76,6 +87,9 @@ public class History implements Serializable {
 	 */
 	public void removeSatellitePage( Page page ) {
 		if ( page == null )	return;
+		if ( page.getAjaxSupport() == Page.AjaxSupport.SERVER_PUSH ) {
+			comet_stop( page );
+		}
 		removePopup( page );
 	}
 
@@ -134,6 +148,7 @@ public class History implements Serializable {
 				}
 			}
 			if ( page.isAllowHistoryAdd() ) {
+				setInfo( page );
 				hist.add( page );
 				page.setHistoryKey( histry_no );
 			}
@@ -144,6 +159,13 @@ public class History implements Serializable {
 		}
 	}
 
+	private void setInfo( Page page ) {
+		if ( page.getPageServerInformation() != null )	return;
+		Page	old = getPage();
+		if ( old == null )	return;
+		page.setPageServerInformation( old.getPageServerInformation() );
+	}
+
 	/**
 	 * 履歴の件数を取得。
 	 * @return 履歴件数。
