@@ -38,6 +38,7 @@ class OutputCall {
 	void call_main() throws Throwable {
 		next_page.setRequestParameter( req );
 		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
+		data.hist.forceNewNo( next_page.getHistoryKey() );
 		data.hist.get( next_page.getHistoryKey() ).add( next_page );
 		Page	view = SandBox.output( next_page, last_page, req );
 		if ( view == null )	view = next_page;
@@ -58,7 +59,11 @@ class OutputCall {
 				next_page = last_page;
 			}
 			else if ( next_page.isAllowHistoryAdd() ) {
-				Page	sub = data.hist.get( next_key ).getPage( next_page.getID() );
+				Page	sub = null;
+				History	history = data.hist.get( next_key );
+				if ( history != null ) {
+					sub = history.getPage( next_page.getID() );
+				}
 				if ( sub != null ) {
 					next_page.getID().getPageFactory().returnPage( next_page );
 					next_page = sub;
@@ -87,6 +92,7 @@ class OutputCall {
 	}
 
 	PostBack[] make() throws Exception {
+		data.hist.forceNewNo( next_key );
 		return make( data.hist.get( next_key ), next_page, out, true );
 	}
 }
@@ -134,6 +140,7 @@ class OpenOutput extends OutputCall {
 				next_page, next_page
 			};
 		}
+		data.hist.forceNewNo( next_key );
 		return make( (Popup)forward, data.hist.get( next_key ), next_page, out[1], true );
 	}
 }
@@ -152,6 +159,7 @@ class CloseOutput extends OutputCall {
 	}
 
 	PostBack[] make() throws Exception {
+		data.hist.forceNewNo( next_key );
 		return make( (Closure)forward, data.hist.get( next_key ), next_page );
 	}
 }
@@ -204,6 +212,7 @@ class LocationOutput extends OutputCall {
 	}
 
 	PostBack[] make() throws Exception {
+		data.hist.forceNewNo( next_key );
 		data.hist.get( next_key ).add( next_page );
 		Forward	fw = forward;
 		if ( !forward.isLeave() ) {
