@@ -1,6 +1,6 @@
 /*
  * Paraselene
- * Copyright (c) 2009  Akira Terasaki
+ * Copyright (c) 2009, 2010  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
  * 利用可能です。
  */
@@ -68,6 +68,15 @@ public class RequestItem implements Serializable {
 		return value.get( no );
 	}
 
+	/**
+	 * 設定値またはファイル名の取得。
+	 * getValue( 0 ) と等価です。
+	 * @return 設定値。
+	 */
+	public String getValue() {
+		return getValue( 0 );
+	}
+
 	/**
 	 * 設定値またはファイル名の取得。全ての設定値を配列にして返します。
 	 * @return 設定値。
