@@ -605,14 +605,9 @@ public class RequestParameter implements Serializable {
 	 * @return 画面遷移履歴キー。name が未登録であれば -1。
 	 */
 	public int getHistoryKey( String name ) {
-		HttpSession	session = getSession();
-		SessionData	data = null;
-		if ( session != null ) {
-			data = (SessionData)session.getAttribute( Supervisor.SESSION_DATA );
-		}
-		if ( data == null )	data = Supervisor.getSessionData( getSupervisor() );
-		if ( data == null )	return -1;
-		return data.hist.getKey( name );
+		HistorySet	set = getHistorySet();
+		if ( set == null )	return -1;
+		return set.getKey( name );
 	}
 
 	/**
@@ -621,6 +616,16 @@ public class RequestParameter implements Serializable {
 	 * @return 履歴。
 	 */
 	public History getHistory( int key ) {
+		HistorySet	set = getHistorySet();
+		if ( set == null )	return null;
+		return set.get( key );
+	}
+
+	/**
+	 * 履歴セットの取得。
+	 * @return 履歴セット。
+	 */
+	public HistorySet getHistorySet() {
 		HttpSession	session = getSession();
 		SessionData	data = null;
 		if ( session != null ) {
@@ -628,7 +633,7 @@ public class RequestParameter implements Serializable {
 		}
 		if ( data == null )	data = Supervisor.getSessionData( getSupervisor() );
 		if ( data == null )	return null;
-		return data.hist.get( key );
+		return data.hist;
 	}
 
 	/**
@@ -654,7 +659,7 @@ public class RequestParameter implements Serializable {
 	 * @return 項目名の配列。
 	 */
 	public String[] getAllKey() {
-		int	cnt = item_map.size();
+		int	cnt = getItemCount();
 		String[]	ret = new String[cnt];
 		int	i = 0;
 		for ( String k: item_map.keySet() ) {
@@ -664,6 +669,14 @@ public class RequestParameter implements Serializable {
 		return ret;
 	}
 
+	/**
+	 * リクエスト項目数の取得。
+	 * @return リクエスト項目数。
+	 */
+	public int getItemCount() {
+		return item_map.size();
+	}
+
 	/**
 	 * リクエストクエリーの有無。
 	 * @return true:クエリーがある、false:クエリーがない。
