@@ -189,6 +189,17 @@ class Child extends Thread implements DaemonChannel {
 		}
 
 		PageHooker[]	hook = page.getPageHooker();
+		if ( page.isAjax() ) {
+			Tag[]	t = page.getModifiedTag();
+			ArrayList<PageHooker>	list = new ArrayList<PageHooker>();
+			for ( int i = 0; i < t.length; i++ ) {
+				PageHooker[]	tmp = t[i].getInnerHTMLPart( hook );
+				for ( int j = 0; j < tmp.length; j++ ) {
+					list.add( tmp[j] );
+				}
+			}
+			hook = list.toArray( new PageHooker[0] );
+		}
 		for ( int i = 0; i < hook.length; i++ ) {
 			hook[i].afterOutput( from, old, req );
 		}
@@ -238,7 +249,7 @@ class Child extends Thread implements DaemonChannel {
 		commitPage();
 		if ( kbt != null )	th = kbt;
 		try {
-			th.printStackTrace();
+			if ( th != null )	th.printStackTrace();
 			daemon.onDestroy( th );
 		}
 		finally {
