@@ -67,17 +67,9 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 	private HashMap<PageID, RedirectData>	pending = new HashMap<PageID, RedirectData>();
 	private volatile int client;
 
-
-	private String cut( String org, int len ) {
-		if ( org == null )	return null;
-		int	org_len = org.length();
-		if ( org_len < len )	len = org_len;
-		return org.substring( 0, len );
-	}
-
 	private int getClient( HttpServletRequest req ) {
 		String[]	data = new String[] {
-			cut( req.getHeader( RequestParameter.UA_HEAD ), 80 ),
+			req.getHeader( RequestParameter.UA_HEAD ),
 			req.getRemoteAddr()
 		};
 		StringBuilder	buf = new StringBuilder();
@@ -91,7 +83,7 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 		return str.hashCode();
 	}
 
-	SessionData( HttpServletRequest req ) {
+	SessionData( HttpServletRequest req ) throws ParaseleneException {
 		client = getClient( req );
 		hist = new HistorySet( req.getSession().getId() );
 	}
