@@ -23,6 +23,12 @@ import javax.servlet.http.*;
  * サイト制御(ファイルアップロード機能なし)。
  */
 public abstract class Supervisor extends HttpServlet {
+	class ExceptionTooLong extends Exception {
+		ExceptionTooLong( Throwable e ) {
+			super( e );
+		}
+	}
+
 	/**
 	 * 不正リクエスト。
 	 */
@@ -31,6 +37,10 @@ public abstract class Supervisor extends HttpServlet {
 		 * 処理済みリクエストの再呼び出し。
 		 */
 		REPEAT_SAME_REQUEST,
+		/**
+		 * リクエスト内容と履歴内容が一致しない。
+		 */
+		DISAPPROVAL_REQUEST,
 		/**
 		 * 呼び出し元ページが履歴に存在しない。
 		 */
@@ -184,7 +194,7 @@ public abstract class Supervisor extends HttpServlet {
 	 * @param tag タグ。
 	 * @return セッション情報が追加されたURI。
 	 */
-	public static String makeWithSessionURI( String uri, String enc, Tag tag ) throws UnsupportedEncodingException {
+	public static String makeWithSessionURI( String uri, String enc, Tag tag ) throws UnsupportedEncodingException, ParaseleneException {
 		boolean	xml_f = false;
 		Page	page = null;
 		if ( tag != null ) {
@@ -343,7 +353,7 @@ public abstract class Supervisor extends HttpServlet {
 			e2.printStackTrace();
 			onError( e2 );
 		}
-		if ( !(e instanceof SocketException) ) {
+		if ( !(e instanceof SocketException) && status != 413 ) {
 			HttpSession	session = req.getSession( false );
 			clear_session( session );
 		}
@@ -381,7 +391,7 @@ public abstract class Supervisor extends HttpServlet {
 		try {
 			if ( data == null ) {
 				System.out.println( "SessionData null" );
-				res.sendError( 500 );
+				ErrorStatus.send( res, 500 );
 				return;
 			}
 
@@ -460,10 +470,7 @@ public abstract class Supervisor extends HttpServlet {
 						fw.Action( this, res );
 						return;
 					}
-					fw = onIllegalRequest( IllegalRequest.SESSION_ERROR, req, last_page, next_page );
-					if ( fw == null || fw.getStatus() == 0 ) {
-						fw = new Forward( 403 );
-					}
+					fw = new Forward( 403 );
 					fw.Action( this, res );
 					clear_session( session );
 					return;
@@ -543,7 +550,20 @@ public abstract class Supervisor extends HttpServlet {
 					to_key = path_data.to_histry;
 				}
 				Page	do_page = last_page.reflect( req );
-				if ( do_page != null && do_page != last_page ) {
+				if ( do_page == null && !(last_page instanceof NullPage) && req.getItemCount() > 0 ) {
+					fw = onIllegalRequest( IllegalRequest.DISAPPROVAL_REQUEST, req, last_page, next_page );
+					if ( fw != null ) {
+						session_f = fw.session_clear_f;
+						last_page = fact.getNullPage();
+						next_page = fw.getPage( null );
+						if ( next_page == null ) {
+							fw.Action( this, res );
+							if ( session_f )	clear_session( session );
+							return;
+						}
+					}
+				}
+				else if ( do_page != null && do_page != last_page ) {
 					last_page = do_page;
 				}
 				last_page.setRequestParameter( req );
@@ -862,10 +882,18 @@ public abstract class Supervisor extends HttpServlet {
 	 */
 	public abstract int getRequestMaxCount();
 
-	private Forward preset( RequestParameter.Method method, HttpServletRequest request, HttpServletResponse res ) throws UnsupportedEncodingException, IOException {
-		if ( !SandBox.isSafeFreeMemory() ) {
-			return new Forward( 503 );
-		}
+	private Forward preset(
+		RequestParameter.Method method,
+		HttpServletRequest request,
+		HttpServletResponse res
+	) throws
+		UnsupportedEncodingException,
+		IOException,
+		ParaseleneException
+	{
+		if ( !SandBox.isSafeFreeMemory() )	return new Forward( 503 );
+		PageFactory	fact = getPageFactory();
+		if ( fact.teapot_f )	return new Forward( 418 );
 		DataHolder	holder = new DataHolder( this, request );
 		HttpSession	session = request.getSession( false );
 		SessionData	data = null;
@@ -891,7 +919,7 @@ public abstract class Supervisor extends HttpServlet {
 		holder.response = res;
 		holder.data = data;
 
-		PathData	p = TransactionSequencer.parsePath( null, request.getRequestURI() , getPageFactory(), null );
+		PathData	p = TransactionSequencer.parsePath( null, request.getRequestURI() , fact, null );
 		if ( p != null ) {
 			if ( p.from != null ) {
 				request.setCharacterEncoding( p.from.getCharset() );
@@ -901,6 +929,9 @@ public abstract class Supervisor extends HttpServlet {
 		try {
 			req = parseRequest( request, p );
 		}
+		catch( ExceptionTooLong tl ) {
+			return onErrorDebug( tl.getCause(), request, res, 413 );
+		}
 		catch( Exception e ){
 			return onErrorDebug( e, request, res, 422 );
 		}
