@@ -142,7 +142,7 @@ public class TransactionSequencer implements Serializable {
 		return ret;
 	}
 
-	static PathData parsePath( TransactionSequencer seq, String uri, PageFactory fact, HistorySet hset ) {
+	static PathData parsePath( TransactionSequencer seq, String uri, PageFactory fact, HistorySet hset ) throws ParaseleneException {
 		String[]	path = uri.split( "\\?" );
 		if ( path != null )	uri = path[0];
 		path = uri.split( "/" );
