@@ -23,9 +23,9 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 	private static final String	ANCHOR_URL_ID = "paraselene$anchor$dummy";
 
 	private boolean fix_id_f = false;
-	private static byte seq = 0;
+	private static volatile byte seq = 0;
 
-	private static String make_id() {
+	private String make_id() {
 		long d = 0;
 		synchronized( ANCHOR_ID ) {
 			seq++;
@@ -79,13 +79,13 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 			URIValue	uv = (URIValue)href.get();
 			QueryItem[]	item = uv.getQuery();
 			ArrayList<QueryItem>	list = new ArrayList<QueryItem>();
-			boolean	flag = false;
 			for ( int i = 0; i < item.length; i++ ) {
 				if ( Form.PAGE_UKEY.equals( item[i].getName() ) ||
 					ANCHOR_ID.equals( item[i].getName() ) ||
 					ANCHOR_URL_ID.equals( item[i].getName() )
 				) {
-					if ( !isClicked() )	continue;
+					if ( isClicked() )	continue;
+					return;
 				}
 				list.add( item[i] );
 			}
@@ -93,10 +93,10 @@ public class Anchor extends Tag implements PageHooker, Clickable {
 				list.add( new QueryItem( ANCHOR_URL_ID, make_id() ) );
 			}
 			Page	my_page = getAssignedPage();
-			if ( !req.getSupervisor().getPageFactory().isAlias( url ) ) {
+			if ( my_page.isAjax() && !req.getSupervisor().getPageFactory().isAlias( url ) ) {
 				list.add( new QueryItem( Form.PAGE_UKEY, my_page.getUniqueKey() ) );
-				list.add( new QueryItem( ANCHOR_ID, makeID() ) );
 			}
+			list.add( new QueryItem( ANCHOR_ID, makeID() ) );
 			uv.setQuery( list.toArray( new QueryItem[0] ) );
 		}
 	}
