@@ -12,6 +12,7 @@ import java.net.*;
 import java.math.*;
 import javax.servlet.http.*;
 import paraselene.*;
+import paraselene.ui.*;
 import paraselene.tag.form.*;
 import paraselene.supervisor.*;
 import paraselene.ajax.data.*;
@@ -1166,21 +1167,23 @@ public class Tag extends HTMLPart {
 
 	private ArrayList<HTMLPart> getInnerHTMLPart( ArrayList<HTMLPart> list, ArrayList<HTMLPart> d ) {
 		int	tgt_cnt = d.size();
-		if ( tgt_cnt == 0 )	return list;
+		if ( tgt_cnt <= 0 )	return list;
 		int	cnt = getHTMLPartCount();
 		for ( int i = 0; i < cnt; i++ ) {
 			HTMLPart	data = getHTMLPart( i );
-			for ( int j = tgt_cnt; j >= 0; j-- ) {
+			for ( int j = tgt_cnt - 1; j >= 0; j-- ) {
 				if ( data == d.get( j ) ) {
 					list.add( data );
 					d.remove( data );
 					tgt_cnt--;
-					if ( tgt_cnt == 0 )	return list;
+					if ( tgt_cnt <= 0 )	return list;
 				}
 			}
 			if ( data instanceof Tag ) {
 				Tag	tag = (Tag)data;
 				list = tag.getInnerHTMLPart( list, d );
+				tgt_cnt = d.size();
+				if ( tgt_cnt <= 0 )	return list;
 			}
 		}
 		return list;
@@ -1188,8 +1191,8 @@ public class Tag extends HTMLPart {
 
 	/**
 	 * 内包物の検索。
-	 * 引数で指定されたインスタンス群のうち、this が内包しているもののみを抽出して
-	 * 返します。<br>
+	 * 引数で指定されたインスタンス群のうち、this が内包しているもの
+	 * のみを抽出して返します。<br>
 	 * 直接内包ではなく、再帰的にネストされた要素を検索します。
 	 * @param d 検索対象の集合。
 	 * @return 存在した要素の集合。無ければ空の配列を返します。
@@ -1204,6 +1207,28 @@ public class Tag extends HTMLPart {
 		return getInnerHTMLPart( list, tgt ).toArray( new HTMLPart[0] );
 	}
 
+	/**
+	 * 内包物の検索。
+	 * 引数で指定されたインスタンス群のうち、this が内包しているもの
+	 * のみを抽出して返します。<br>
+	 * 直接内包ではなく、再帰的にネストされた要素を検索します。
+	 * @param d 検索対象の集合。
+	 * @return 存在した要素の集合。無ければ空の配列を返します。
+	 */
+	public PageHooker[] getInnerHTMLPart( PageHooker[] d ) {
+		if ( d == null )	return new PageHooker[0];
+		HTMLPart[]	ret = new HTMLPart[d.length];
+		for ( int i = 0; i < ret.length; i++ ){
+			ret[i] = (HTMLPart)d[i];
+		}
+		ret = getInnerHTMLPart( ret );
+		d = new PageHooker[ret.length];
+		for ( int i = 0; i < ret.length; i++ ){
+			d[i] = (PageHooker)ret[i];
+		}
+		return d;
+	}
+
 	/**
 	 * 内包物の検索。
 	 * 引数で指定されたインスタンス群のうち、this が内包しているもので
