@@ -56,7 +56,7 @@ public class Form extends Tag implements PageHooker {
 	private static HashMap<String, String>	skip_name = new HashMap<String, String>();
 
 	private static FormSeq	form_seq = new FormSeq();
-	private	String	seq;
+	private	String	seq = "-1";
 	private HashMap<String, HashMap<String,Control>>	control = new HashMap<String, HashMap<String,Control>>();
 	private boolean fixed_f = false;
 
@@ -67,6 +67,13 @@ public class Form extends Tag implements PageHooker {
 		skip_name.put( PAGE_UKEY, PAGE_UKEY );
 	}
 
+	/**
+	 * フレームワークが使用します。
+	 */
+	public static boolean isFixedName( String name ) {
+		return skip_name.get( name ) != null;
+	}
+
 	/**
 	 * コントロールインスタンスが存在するか？
 	 * @param cont 検証するインスタンス。
@@ -81,6 +88,7 @@ public class Form extends Tag implements PageHooker {
 		return map.get( name ) == cont;
 	}
 
+	private Input	form_ukey = Input.createHidden( FORM_ID, "-1" );
 	private Input	page_ukey = Input.createHidden( PAGE_UKEY, "-1" );
 
 	/**
@@ -88,25 +96,23 @@ public class Form extends Tag implements PageHooker {
 	 */
 	public Form() {
 		super( "form", false );
-		seq = form_seq.getSeq();
 		Input[]	id = new Input[] {
-			Input.createHidden( FORM_ID, seq ),
+			form_ukey,
 			Input.createHidden( FORM_AJAX, "-1" ),
 			Input.createHidden( FORM_DUMMY, "-1" ),
 			page_ukey
 		};
 		addHTMLPart( id );
 		setAttribute( "method", "POST" );
+		setID();
 		fixed_f = true;
 	}
 
 	public void addHTMLPart( int idx, HTMLPart d ) {
 		if ( fixed_f && d instanceof Input ) {
 			Input	ip = (Input)d;
-			if ( ip.input_type == Input.Type.HIDDEN ) {
-				String	name = ip.getNameAttribute();
-				if ( FORM_ID.equals( name ) || FORM_AJAX.equals( name ) )	return;
-			}
+			String	name = ip.getNameAttribute();
+			if ( isFixedName( name ) )	return;
 		}
 		super.addHTMLPart( idx, d );
 	}
@@ -115,9 +121,20 @@ public class Form extends Tag implements PageHooker {
 		return fw;
 	}
 
+	private void setID() {
+		seq = form_seq.getSeq();
+		form_ukey.setValueString( seq );
+	}
+
 	public void afterOutput( Page from, Page to, RequestParameter req ) throws Exception {
 		commitDaemon();
-		page_ukey.setValueString( getAssignedPage().getUniqueKey() );
+		Page	my_page = getAssignedPage();
+		if ( my_page.isAjax() && "-1".equals( page_ukey.getValueString() ) ) {
+			page_ukey.setValueString( my_page.getUniqueKey() );
+		}
+		else if ( !"-1".equals( page_ukey.getValueString() ) ) {
+			page_ukey.setValueString( "-1" );
+		}
 	}
 
 	public void commitDaemon() {
